# IPython kernels for Spyder plugin for modelx

A custom IPython kernels for the `spyder-modelx` package, which is a plug-in for Spyder,
a Scientific Python Development Environment.

These kernels can launched either through Spyder itself or in an independent
Python session, and allow for interactive or file-based execution of Python
code inside Spyder.

Visit the following sites for more details:

* [modelx documentation](https://docs.modelx.io/en/latest/)
* [modelx home page](https://modelx.io)
* [modelx github repository](https://github.com/fumitoh/modelx)
* [spyder-modelx github repository](https://github.com/fumitoh/spyder-modelx)

## Installation

To install this package, you can use either the ``pip`` or ``conda`` package
managers, as follows:

Using conda (the recommended way!):

```
conda install -c conda-forge spymx-kernels
```

Using pip:

```
pip install spymx-kernels
```

## Dependencies

This project depends on:

* [spyder-kernels](https://github.com/spyder-ide/spyder-kernels)



